@@ -1,3 +1,9 @@
+# Copyright (c) 2018 The Pooch Developers.
+# Distributed under the terms of the BSD 3-Clause License.
+# SPDX-License-Identifier: BSD-3-Clause
+#
+# This code is part of the Fatiando a Terra project (https://www.fatiando.org)
+#
 # pylint: disable=redefined-outer-name
 """
 Test the entire process of creating a Pooch and using it.
@@ -25,8 +31,7 @@ def test_create_and_fetch():
     )
     # Make sure the storage isn't created until a download is required
     assert not pup.abspath.exists()
-    # The str conversion is needed in Python 3.5
-    pup.load_registry(str(Path(os.path.dirname(__file__), "data", "registry.txt")))
+    pup.load_registry(Path(os.path.dirname(__file__), "data", "registry.txt"))
     for target in ["tiny-data.txt", "subdir/tiny-data.txt"]:
         with capture_log() as log_file:
             fname = pup.fetch(target)
