@@ -1,3 +1,9 @@
+# Copyright (c) 2018 The Pooch Developers.
+# Distributed under the terms of the BSD 3-Clause License.
+# SPDX-License-Identifier: BSD-3-Clause
+#
+# This code is part of the Fatiando a Terra project (https://www.fatiando.org)
+#
 """
 Misc utilities
 """
@@ -93,7 +99,7 @@ def file_hash(fname, alg="sha256"):
 
     """
     if alg not in hashlib.algorithms_available:
-        raise ValueError("Algorithm '{}' not available in hashlib".format(alg))
+        raise ValueError(f"Algorithm '{alg}' not available in hashlib")
     # Calculate the hash in chunks to avoid overloading the memory
     chunksize = 65536
     hasher = hashlib.new(alg)
@@ -281,14 +287,12 @@ def make_local_storage(path, env=None):
     except PermissionError as error:
         message = [
             str(error),
-            "| Pooch could not {} data cache folder '{}'.".format(action, path),
+            f"| Pooch could not {action} data cache folder '{path}'.",
             "Will not be able to download data files.",
         ]
         if env is not None:
             message.append(
-                "Use environment variable '{}' to specify a different location.".format(
-                    env
-                )
+                f"Use environment variable '{env}' to specify a different location."
             )
         raise PermissionError(" ".join(message)) from error
 
@@ -322,6 +326,8 @@ def hash_algorithm(hash_string):
     md5
     >>> print(hash_algorithm("sha256:qouuwhwd2j192y1lb1iwgowdj2898wd2d9"))
     sha256
+    >>> print(hash_algorithm("SHA256:qouuwhwd2j192y1lb1iwgowdj2898wd2d9"))
+    sha256
     >>> print(hash_algorithm(None))
     sha256
 
@@ -333,7 +339,7 @@ def hash_algorithm(hash_string):
         algorithm = default
     else:
         algorithm = hash_string.split(":")[0]
-    return algorithm
+    return algorithm.lower()
 
 
 def hash_matches(fname, known_hash, strict=False, source=None):
@@ -342,6 +348,9 @@ def hash_matches(fname, known_hash, strict=False, source=None):
 
     If the *known_hash* is None, will always return True.
 
+    Coverts hashes to lowercase before comparison to avoid system specific
+    mismatches between hashes in the registry and computed hashes.
+
     Parameters
     ----------
     fname : str or PathLike
@@ -368,20 +377,15 @@ def hash_matches(fname, known_hash, strict=False, source=None):
         return True
     algorithm = hash_algorithm(known_hash)
     new_hash = file_hash(fname, alg=algorithm)
-    matches = new_hash == known_hash.split(":")[-1]
+    matches = new_hash.lower() == known_hash.split(":")[-1].lower()
     if strict and not matches:
         if source is None:
             source = str(fname)
         raise ValueError(
-            "{} hash of downloaded file ({}) does not match the known hash:"
-            " expected {} but got {}. Deleted download for safety."
-            " The downloaded file may have been corrupted or"
-            " the known hash may be outdated.".format(
-                algorithm.upper(),
-                source,
-                known_hash,
-                new_hash,
-            )
+            f"{algorithm.upper()} hash of downloaded file ({source}) does not match"
+            f" the known hash: expected {known_hash} but got {new_hash}. Deleted"
+            " download for safety. The downloaded file may have been corrupted or"
+            " the known hash may be outdated."
         )
     return matches
 
@@ -456,5 +460,5 @@ def unique_file_name(url):
     # Crop the start of the file name to fit 255 characters including the hash
     # and the :
     fname = fname[-(255 - len(md5) - 1) :]
-    unique_name = "{}-{}".format(md5, fname)
+    unique_name = f"{md5}-{fname}"
     return unique_name
